pub struct ObjectDestructorHandle<'a, D: ObjectDestructor> { /* private fields */ }Expand description
The handle for the ObjectDestructor.
Once this handle is dropped, the destructor will be unregistered and the associated resources will be cleaned up.