pub trait ObjectDestructor:
'static
+ Sync
+ Sized {
// Provided methods
fn destruct_view(&self, _view: &BinaryView) { ... }
fn destruct_file_metadata(&self, _metadata: &FileMetadata) { ... }
fn destruct_function(&self, _func: &Function) { ... }
}Expand description
The trait required for receiving core object destruction callbacks.
This is useful for cleaning up resources which are associated with a given core object.
Provided Methods
Sourcefn destruct_view(&self, _view: &BinaryView)
fn destruct_view(&self, _view: &BinaryView)
Called when a BinaryView is about to be destroyed.
Sourcefn destruct_file_metadata(&self, _metadata: &FileMetadata)
fn destruct_file_metadata(&self, _metadata: &FileMetadata)
Called when a FileMetadata is about to be destroyed.
Sourcefn destruct_function(&self, _func: &Function)
fn destruct_function(&self, _func: &Function)
Called when a Function is about to be destroyed.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.